<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name></name>
    <message>
        <source></source>
        <translation>Project-Id-Version: PACKAGE VERSION
Report-Msgid-Bugs-To: 
POT-Creation-Date: 2008-11-12 21:25+0200
PO-Revision-Date: 2009-12-17 09:00+0000
Last-Translator: Андрей Стрепетов &lt;Unknown&gt;
Language-Team: LANGUAGE &lt;LL@li.org&gt;
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-Launchpad-Export-Date: 2009-12-26 10:24+0000
X-Generator: Launchpad (build Unknown)
</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation>Комп&apos;ютер</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Сервіс</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Відкриття файла</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Показати активність SMB/CIFS</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Мінімізувати</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Відновити</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Подяки:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>Ця программа розповсюджується під ліцензією GNU General Public License версії 2</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Найти текст</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Текст не знайдено.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Користувач %1 відкрив ресурс %2 (%3)</translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Користувач %1 відкрив файл %2 (%3)</translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>Активність SMB/CIFS</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Повідомлення</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Повідомлення для %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Ви бажаєте від&apos;єднати користувача %1 ?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Так</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Ні</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Властивості</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Повідомлення всім користувачам</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Повідомлення для</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Від&apos;єднати користувача</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation>Доступне оновлення</translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation>Доступна нова версія %1</translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation>Ви можете завантажити тут: %1</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Інтервал:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Інтервал між запитами smbstatus в секундах (інтервал &gt; 2)</translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation>Показати приховані ресурси (share$)</translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation>Показати приховані ресурси</translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation>Повідомлення та звіт</translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation>Ліміт звіту:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>днів</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Іконка QtSmbstatus в треї</translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Активність в &quot;плаваючих повідомленнях&quot;</translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation>Повідомлення статусу</translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation>Звіт активності SMB/CIFS</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ТАК</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Відміна</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Різне</translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation>Автоматично первіряти наявність оновлень</translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation>З&apos;явилась нова версія</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>З&apos;єднання</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Користувач за умовчанням:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Автоз&apos;єднання при старті qtsmbstatus</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Автоз&apos;єднання</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Хост за умовчанням:&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation>Користувач (за умовчанням :  користувач = root)</translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Адреса хоста</translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>З&apos;єднання/Від&apos;єднання</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Пошук</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;Про QtSmbstatus</translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Про QtSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Про &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Про Qt</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation>&amp;Конфігурування клієнта</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation>Конфігурування QtSmbstatus клієнта</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation>&amp;Комп&apos;ютер</translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation>Пошук комп&apos;ютера</translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Користувач</translation>
    </message>
    <message>
        <source>Search user</source>
        <translation>Пошук користувача</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation>&amp;Відкриті ресурси</translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation>Пошук відкритих ресурсів</translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation>&amp;Блоковані файли</translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation>Пошук відкритих файлів</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Далі</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Далі</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Найти текст</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Найти текст</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Вихід</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Вийти з QtSmbstatus</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>&amp;Показати активність SMB/CIFS</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>З&apos;&amp;єднання</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Дивитись активність</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation>Зберегти звіт</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation>Показати/сховати ресурси</translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Показати/сховати файли</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Фільтр:</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>З&apos;єднання з сервером qtsmbstatus</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>login</source>
        <translation>логін</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>вихід</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>З&apos;єднання</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation>Процес з&apos;єднання з %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>З&apos;єднано з хостом</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>З&apos;єднання закрите</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Від&apos;єднання</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Неправильний логін чи пароль!</translation>
    </message>
</context>
</TS>
